import { AddressFormat, BaseUtils } from '@bitgo-beta/sdk-core';
import { DRep, Address } from '@emurgo/cardano-serialization-lib-nodejs';
import { KeyPair } from './keyPair';
export declare const MIN_ADA_FOR_ONE_ASSET = "1500000";
export declare const VOTE_ALWAYS_ABSTAIN = "always-abstain";
export declare const VOTE_ALWAYS_NO_CONFIDENCE = "always-no-confidence";
export declare class Utils implements BaseUtils {
    createBaseAddressWithStakeAndPaymentKey(stakeKeyPair: KeyPair, paymentKeyPair: KeyPair, network: AddressFormat): string;
    validateBlake2b(hash: string): boolean;
    getRewardAddress(stakingPubKey: string, coinName: string): string;
    isValidDRepId(dRepId: string): boolean;
    getDRepFromDRepId(dRepId: string): DRep;
    getDRepIdFromDRep(dRep: DRep): string;
    /** @inheritdoc */
    isValidAddress(address: string): boolean;
    /** @inheritdoc */
    isValidBlockId(hash: string): boolean;
    /** @inheritdoc */
    isValidPrivateKey(key: string): boolean;
    isValidKey(key: string): boolean;
    /** @inheritdoc */
    isValidPublicKey(pubKey: string): boolean;
    /** @inheritdoc */
    isValidSignature(signature: string): boolean;
    /** @inheritdoc */
    isValidTransactionId(txId: string): boolean;
    /**
     * Get the transaction body from a serialized transaction
     * @param {string} serializedTx - serialized transaction in hex or base64 format
     * @returns {string} transaction body in hex format
     */
    getTransactionBody(serializedTx: string): string;
    /**
     * Decode wallet address from string.
     * Attempts to decode as Shelley (bech32) first, then Byron (base58).
     * @param {string} address - Valid Byron or Shelley-era address.
     * @returns {Address} - Valid address object.
     * @throws {InvalidAddressError} If the address is neither valid Shelley nor Byron.
     */
    getWalletAddress(address: string): Address;
    /**
     * Decode address string from Address object.
     * Attempts to decode as Shelley (bech32) first, then Byron (base58).
     * @param {Address} address - Valid Address object
     * @returns {string} - Valid Byron or Shelley-era address string.
     * @throws {InvalidAddressError} If the Address object is neither valid Shelley nor Byron.
     */
    getAddressString(address: Address): string;
}
declare const utils: Utils;
export default utils;
//# sourceMappingURL=utils.d.ts.map